#coding:utf-8
# Django settings for gisdo project.
import os
from multiprocessing.util import register_after_fork

from sqlalchemy import create_engine
from sqlalchemy.pool import NullPool

from kinder import settings as kinder_settings
from kinder.config_parser import ProjectConfig
#-------------------------------------------------------
#: Настройки для Системы показателей
#-------------------------------------------------------
DEFAULT_CONFIG = {
    ('gisdo', 'PUSH_DATA_URL'): '',
    ('gisdo', 'PUSH_DATA_TIMEOUT'): 90,
    ('gisdo', 'FEDERAL_DISTRICT'): '',
    ('gisdo', 'GISDO_LOG_FILE'): 'gisdo.log',
    ('gisdo', 'AGE_CALCULATION_DATE'): 0,
    ('gisdo', 'NO_CONSIDER_PRIORITY'): False,
    ('gisdo', 'NO_TEMPORARY_PUPIL'): False,
}

PROJECT_PATH = os.path.dirname(__file__)
filenames = kinder_settings.CONF_FILES if \
    hasattr(kinder_settings, 'CONF_FILES') \
    else os.path.join(PROJECT_PATH, 'gisdo.conf')

conf = ProjectConfig(filenames=filenames,
                     defaults=DEFAULT_CONFIG)
#: Адрес веб сервиса системы показателей
GISDO_WS_WSDL = conf.get('gisdo', 'PUSH_DATA_URL')
# таймаут на отправку данных
GISDO_TIMEOUT = conf.get_int('gisdo', 'PUSH_DATA_TIMEOUT')
#: Федеральный субъект, в котором установлена система
FEDERAL_DISTRICT = conf.get('gisdo', 'FEDERAL_DISTRICT')
# Файл с логами для данного приложения
GISDO_LOG_FILE = conf.get('gisdo', 'GISDO_LOG_FILE') or 'gisdo.log'
# Вариант расчета возраста ребенка
AGE_CALCULATION_DATE = conf.get_int('gisdo', 'AGE_CALCULATION_DATE')
# Учитывать ли при расчете приоритет учреждения. С отрицанием из-за того чтобы можно было по-умолчанию
# выставить значение "Учитывать".
NO_CONSIDER_PRIORITY = conf.get_bool('gisdo', 'NO_CONSIDER_PRIORITY')
# Учитывать ли временные зачисления
NO_TEMPORARY_PUPIL = conf.get_bool('gisdo', 'NO_TEMPORARY_PUPIL')
# Код региона
REGION_CODE = conf.get('region', 'REGION_CODE') or ''
# Дублирую из садов.
DOWNLOADS_DIR = kinder_settings.DOWNLOADS_DIR
DOWNLOADS_URL = kinder_settings.DOWNLOADS_URL
#у плагина нет синхр. реализации, надо включать celery
CELERY_IMPORTS = kinder_settings.CELERY_IMPORTS if hasattr(kinder_settings, 'CELERY_IMPORTS') else tuple()
CELERY_IMPORTS += ('gisdo.tasks',)

database_engine = kinder_settings.DATABASES['default']
database_name = database_engine.get('NAME', '')
database_user = database_engine.get('USER', '')
database_password = database_engine.get('PASSWORD', '')
database_host = database_engine.get('HOST', '')
database_port = database_engine.get('PORT', '') or 5432
notation = 'postgresql+psycopg2://%s:%s@%s:%s/%s' % (database_user, database_password,
                                                     database_host, database_port,
                                                     database_name)
# Пока без пула.
engine = create_engine(notation, echo=False, poolclass=NullPool)
#https://github.com/celery/celery/issues/1564
register_after_fork(engine, engine.dispose)
